@@ -10,7 +10,7 @@ use LWP::UserAgent;
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(bankValUK new);
-our $VERSION   = '0.05';
+our $VERSION   = '0.06';
 
 my $account;           #account number to be validated
 my $uid;               #userID
@@ -293,13 +293,9 @@ valid parameter lists are:-
 
 bankValUK('$sortcode','$account no.','$userID','$PIN');
 
-bankValUK('$sortcode','$userID','$PIN');
-
 bankValUK('$sortcode','$account no.');
 
-bankValUK('$sortcode');
-
-n.b. the last two parameter lists require that the user ID and PIN are stored
+n.b. the last parameter list requires that the user ID and PIN are stored
 in the I<LoginConfig.txt> file bundled with this module.
 
 
